@@ -263,23 +263,17 @@
 //! Themes can also be customized by defining your own color palette to be used when printing out information.
 
 /// The parser modules contains all functionality for parsing arguments at the command level. It contains some submodules all involved in parsing arguments and flags.
-pub mod parser;
+mod parser;
 
-/// The program module houses the the program struct and all its associated methods for manipulating and adjusting the program settings to customize the look and feel of your cli. It contains multiple `getters` and `setters` that can be used to get any desired values in the program.
-///
-/// The program module contains all functionality for parsing arguments at the program level. It resolves the target command then passes the cleaned argument to the cmd.parse() method.
-pub mod program;
-
-/// The events module contains the EventEmitter functionality and an enum containing all the possible events that can be emitted. It also contains associative methods to `emit` and `listen` to events in the Event enum. When a new instance of a program is created, the program contains an event_emitter instance.
-pub mod events;
+/// A module housing all the core functionality of the library such as events, the program module itself, settings and other core functionality
+mod core;
 
 /// A module to house some utilities used by the crate itself.
-pub mod utils;
+mod utils;
 
 /// The UI module houses the formatter module that is used to print to stdout and the themes module used to construct and define new themes.
-pub mod ui;
+mod ui;
 
-pub use events::{Event, EventEmitter};
-pub use program::Program;
+pub use crate::core::{Event, EventEmitter, Program};
 pub use termcolor::Color;
 pub use ui::{Designation, Formatter, FormatterRules, Pattern, PredefinedThemes, Theme};
